;; Generated package description from flymake.el  -*- no-byte-compile: t -*-
(define-package "flymake" "1.3.6" "A universal on-the-fly syntax checker" '((emacs "26.1") (eldoc "1.14.0") (project "0.7.1")) :commit "9db3fbd369121ddd34e7f4febe8688d758a5dbb7" :url "https://elpa.gnu.org/packages/flymake.html" :authors '(("Pavel Kobyakov" . "pk_at_work@yahoo.com")) :maintainer '("João Távora" . "joaotavora@gmail.com") :keywords '("c" "languages" "tools"))
